Struct
GeglMatrix3
Constructors
gegl_matrix3_new
Instance methods
gegl_matrix3_copy
Returns a copy of src.
gegl_matrix3_copy_into
Copies the matrix in src into dst.
gegl_matrix3_determinant
Returns the determinant for the matrix.
gegl_matrix3_equal
Check if two matrices are equal.
gegl_matrix3_identity
Set the provided matrix to the identity matrix.
gegl_matrix3_invert
Inverts matrix.
gegl_matrix3_is_affine
Check if a matrix only does an affine transformation.
gegl_matrix3_is_identity
Check if a matrix is the identity matrix.
gegl_matrix3_is_scale
Check if a matrix only does scaling.
gegl_matrix3_is_translate
Check if a matrix only does translation.
gegl_matrix3_multiply
Multiples product = left · right.
gegl_matrix3_originate
Shift the origin of the transformation specified by matrix
to (x, y). In other words, calculate the matrix that:
gegl_matrix3_parse_string
Parse a transofmation matrix from a string.
gegl_matrix3_round_error
Rounds numerical errors in matrix to the nearest integer.
gegl_matrix3_to_string
Serialize a GeglMatrix3 to a string.
gegl_matrix3_transform_point
Transforms the coordinates provided in x and y and changes to the
coordinates gotten when the transformed with the matrix.